Axis and Locator ``pan`` and ``zoom``
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
The unused ``pan`` and ``zoom`` methods of `~.axis.Axis` and `~.ticker.Locator`
have been removed.  Panning and zooming are now implemented using the
``start_pan``, ``drag_pan``, and ``end_pan`` methods of `~.axes.Axes`.

Ticker Locators and Formatters
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

The following deprecated `.Locator`\s and `.Formatter`\s have been removed:

* ``OldScalarFormatter``, ``IndexFormatter`` and ``IndexDateFormatter``; use
  `.FuncFormatter` instead.
* ``OldAutoLocator``

The following deprecated properties and methods have been removed:

* ``DateFormatter.illegal_s``
* ``Locator.refresh()`` and the associated helper methods
  ``NavigationToolbar2.draw()`` and ``ToolViewsPositions.refresh_locators()``
